# 🌐 pocean-core

[![Push](https://github.com/pyoceans/pocean-core/actions/workflows/push.yml/badge.svg)](https://github.com/pyoceans/pocean-core/actions/workflows/push.yml)
[![license](https://img.shields.io/github/license/pyoceans/pocean-core.svg)](https://github.com/pyoceans/pocean-core/blob/master/LICENSE.txt)
[![GitHub release](https://img.shields.io/github/release/pyoceans/pocean-core/all.svg)](https://pypi.org/project/pocean-core/)


🐍 + 🌊

A python framework for working with met-ocean data

## Resources
+ **Documentation:** <https://pyoceans.github.io/pocean-core/docs/>
+ **API:** <https://pyoceans.github.io/pocean-core/docs/api/pocean.html>
+ **Source Code:** <https://github.com/pyoceans/pocean-core/>
+ **Git clone URL:** <https://github.com/pyoceans/pocean-core.git>
